# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/storage/v1/bucket.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/storage/v1/bucket.proto',
  package='yandex.cloud.storage.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storage',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$yandex/cloud/storage/v1/bucket.proto\x12\x17yandex.cloud.storage.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dyandex/cloud/validation.proto\"\xa8\x04\n\x06\x42ucket\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tfolder_id\x18\x03 \x01(\t\x12M\n\x16\x61nonymous_access_flags\x18\x04 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12\x1d\n\x15\x64\x65\x66\x61ult_storage_class\x18\x05 \x01(\t\x12\x37\n\nversioning\x18\x06 \x01(\x0e\x32#.yandex.cloud.storage.v1.Versioning\x12\x10\n\x08max_size\x18\x07 \x01(\x03\x12\'\n\x06policy\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x03\x61\x63l\x18\t \x01(\x0b\x32\x1c.yandex.cloud.storage.v1.ACL\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x04\x63ors\x18\x0b \x03(\x0b\x32!.yandex.cloud.storage.v1.CorsRule\x12\x42\n\x10website_settings\x18\x0c \x01(\x0b\x32(.yandex.cloud.storage.v1.WebsiteSettings\x12?\n\x0flifecycle_rules\x18\r \x03(\x0b\x32&.yandex.cloud.storage.v1.LifecycleRule\"\x92\x04\n\x03\x41\x43L\x12\x32\n\x06grants\x18\x01 \x03(\x0b\x32\".yandex.cloud.storage.v1.ACL.Grant\x1a\xd6\x03\n\x05Grant\x12G\n\npermission\x18\x01 \x01(\x0e\x32-.yandex.cloud.storage.v1.ACL.Grant.PermissionB\x04\xe8\xc7\x31\x01\x12\x46\n\ngrant_type\x18\x02 \x01(\x0e\x32,.yandex.cloud.storage.v1.ACL.Grant.GrantTypeB\x04\xe8\xc7\x31\x01\x12\x12\n\ngrantee_id\x18\x03 \x01(\t\"\xa3\x01\n\nPermission\x12\x1a\n\x16PERMISSION_UNSPECIFIED\x10\x00\x12\x1b\n\x17PERMISSION_FULL_CONTROL\x10\x01\x12\x14\n\x10PERMISSION_WRITE\x10\x02\x12\x18\n\x14PERMISSION_WRITE_ACP\x10\x03\x12\x13\n\x0fPERMISSION_READ\x10\x04\x12\x17\n\x13PERMISSION_READ_ACP\x10\x05\"\x81\x01\n\tGrantType\x12\x1a\n\x16GRANT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12GRANT_TYPE_ACCOUNT\x10\x01\x12&\n\"GRANT_TYPE_ALL_AUTHENTICATED_USERS\x10\x02\x12\x18\n\x14GRANT_TYPE_ALL_USERS\x10\x03\"\x9b\x01\n\x14\x41nonymousAccessFlags\x12(\n\x04read\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12(\n\x04list\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12/\n\x0b\x63onfig_read\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\"\xe4\x02\n\x08\x43orsRule\x12\n\n\x02id\x18\x01 \x01(\t\x12M\n\x0f\x61llowed_methods\x18\x02 \x03(\x0e\x32(.yandex.cloud.storage.v1.CorsRule.MethodB\n\x82\xc8\x31\x02>0\x90\xc8\x31\x01\x12\x17\n\x0f\x61llowed_headers\x18\x03 \x03(\t\x12\x1f\n\x0f\x61llowed_origins\x18\x04 \x03(\tB\x06\x82\xc8\x31\x02>0\x12\x16\n\x0e\x65xpose_headers\x18\x05 \x03(\t\x12\x34\n\x0fmax_age_seconds\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"u\n\x06Method\x12\x16\n\x12METHOD_UNSPECIFIED\x10\x00\x12\x0e\n\nMETHOD_GET\x10\x01\x12\x0f\n\x0bMETHOD_HEAD\x10\x02\x12\x0f\n\x0bMETHOD_POST\x10\x03\x12\x0e\n\nMETHOD_PUT\x10\x04\x12\x11\n\rMETHOD_DELETE\x10\x05\"\xbc\x06\n\x0fWebsiteSettings\x12\r\n\x05index\x18\x01 \x01(\t\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12N\n\x15redirect_all_requests\x18\x03 \x01(\x0b\x32/.yandex.cloud.storage.v1.WebsiteSettings.Scheme\x12K\n\rrouting_rules\x18\x04 \x03(\x0b\x32\x34.yandex.cloud.storage.v1.WebsiteSettings.RoutingRule\x1a_\n\x06Scheme\x12\x43\n\x08protocol\x18\x01 \x01(\x0e\x32\x31.yandex.cloud.storage.v1.WebsiteSettings.Protocol\x12\x10\n\x08hostname\x18\x02 \x01(\t\x1aO\n\tCondition\x12\'\n\x1fhttp_error_code_returned_equals\x18\x01 \x01(\t\x12\x19\n\x11key_prefix_equals\x18\x02 \x01(\t\x1a\xd2\x01\n\x08Redirect\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\x34\n\x12http_redirect_code\x18\x02 \x01(\tB\x18\xf2\xc7\x31\x14\x33(0[1-9]|[1-9][0-9])\x12\x43\n\x08protocol\x18\x03 \x01(\x0e\x32\x31.yandex.cloud.storage.v1.WebsiteSettings.Protocol\x12\x1f\n\x17replace_key_prefix_with\x18\x04 \x01(\t\x12\x18\n\x10replace_key_with\x18\x05 \x01(\t\x1a\x99\x01\n\x0bRoutingRule\x12\x45\n\tcondition\x18\x01 \x01(\x0b\x32\x32.yandex.cloud.storage.v1.WebsiteSettings.Condition\x12\x43\n\x08redirect\x18\x02 \x01(\x0b\x32\x31.yandex.cloud.storage.v1.WebsiteSettings.Redirect\"K\n\x08Protocol\x12\x18\n\x14PROTOCOL_UNSPECIFIED\x10\x00\x12\x11\n\rPROTOCOL_HTTP\x10\x01\x12\x12\n\x0ePROTOCOL_HTTPS\x10\x02\"\xf8\x08\n\rLifecycleRule\x12(\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x41\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x31.yandex.cloud.storage.v1.LifecycleRule.RuleFilter\x12\x45\n\nexpiration\x18\x04 \x01(\x0b\x32\x31.yandex.cloud.storage.v1.LifecycleRule.Expiration\x12\x46\n\x0btransitions\x18\x05 \x03(\x0b\x32\x31.yandex.cloud.storage.v1.LifecycleRule.Transition\x12[\n!abort_incomplete_multipart_upload\x18\x06 \x01(\x0b\x32\x30.yandex.cloud.storage.v1.LifecycleRule.AfterDays\x12Z\n\x15noncurrent_expiration\x18\x07 \x01(\x0b\x32;.yandex.cloud.storage.v1.LifecycleRule.NoncurrentExpiration\x12[\n\x16noncurrent_transitions\x18\x08 \x03(\x0b\x32;.yandex.cloud.storage.v1.LifecycleRule.NoncurrentTransition\x1aG\n\tAfterDays\x12:\n\x15\x64\x61ys_after_expiration\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1aL\n\x14NoncurrentExpiration\x12\x34\n\x0fnoncurrent_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x1ai\n\x14NoncurrentTransition\x12\x34\n\x0fnoncurrent_days\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1b\n\rstorage_class\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\x1a~\n\nTransition\x12(\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x04\x64\x61ys\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x1b\n\rstorage_class\x18\x04 \x01(\tB\x04\xe8\xc7\x31\x01\x1a\xa3\x01\n\nExpiration\x12(\n\x04\x64\x61te\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12)\n\x04\x64\x61ys\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12@\n\x1c\x65xpired_object_delete_marker\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x1a\x1c\n\nRuleFilter\x12\x0e\n\x06prefix\x18\x01 \x01(\t\"\xdd\x01\n\x08\x43ounters\x12\x1a\n\x12simple_object_size\x18\x01 \x01(\x03\x12\x1b\n\x13simple_object_count\x18\x02 \x01(\x03\x12\x1a\n\x12objects_parts_size\x18\x03 \x01(\x03\x12\x1b\n\x13objects_parts_count\x18\x04 \x01(\x03\x12\x1e\n\x16multipart_objects_size\x18\x05 \x01(\x03\x12\x1f\n\x17multipart_objects_count\x18\x06 \x01(\x03\x12\x1e\n\x16\x61\x63tive_multipart_count\x18\x07 \x01(\x03\"]\n\x13OptionalSizeByClass\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12/\n\nclass_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"8\n\x0bSizeByClass\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12\x12\n\nclass_size\x18\x02 \x01(\x03\"]\n\x0f\x43ountersByClass\x12\x15\n\rstorage_class\x18\x01 \x01(\t\x12\x33\n\x08\x63ounters\x18\x02 \x01(\x0b\x32!.yandex.cloud.storage.v1.Counters\"\xaa\x04\n\x0b\x42ucketStats\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\x08max_size\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x11\n\tused_size\x18\x03 \x01(\x03\x12M\n\x17storage_class_max_sizes\x18\x04 \x03(\x0b\x32,.yandex.cloud.storage.v1.OptionalSizeByClass\x12\x46\n\x18storage_class_used_sizes\x18\x05 \x03(\x0b\x32$.yandex.cloud.storage.v1.SizeByClass\x12H\n\x16storage_class_counters\x18\x06 \x03(\x0b\x32(.yandex.cloud.storage.v1.CountersByClass\x12;\n\x15\x64\x65\x66\x61ult_storage_class\x18\x07 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12M\n\x16\x61nonymous_access_flags\x18\x08 \x01(\x0b\x32-.yandex.cloud.storage.v1.AnonymousAccessFlags\x12.\n\ncreated_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xc1\x03\n\x0bHTTPSConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x44\n\x0bsource_type\x18\x02 \x01(\x0e\x32/.yandex.cloud.storage.v1.HTTPSConfig.SourceType\x12,\n\x06issuer\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12-\n\x07subject\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x11\n\tdns_names\x18\x05 \x03(\t\x12.\n\nnot_before\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tnot_after\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x16\n\x0e\x63\x65rtificate_id\x18\x08 \x01(\t\"w\n\nSourceType\x12\x1b\n\x17SOURCE_TYPE_UNSPECIFIED\x10\x00\x12\x1c\n\x18SOURCE_TYPE_SELF_MANAGED\x10\x01\x12.\n*SOURCE_TYPE_MANAGED_BY_CERTIFICATE_MANAGER\x10\x02*s\n\nVersioning\x12\x1a\n\x16VERSIONING_UNSPECIFIED\x10\x00\x12\x17\n\x13VERSIONING_DISABLED\x10\x01\x12\x16\n\x12VERSIONING_ENABLED\x10\x02\x12\x18\n\x14VERSIONING_SUSPENDED\x10\x03\x42\x62\n\x1byandex.cloud.api.storage.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/storage/v1;storageb\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])

_VERSIONING = _descriptor.EnumDescriptor(
  name='Versioning',
  full_name='yandex.cloud.storage.v1.Versioning',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VERSIONING_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERSIONING_DISABLED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERSIONING_ENABLED', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VERSIONING_SUSPENDED', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5255,
  serialized_end=5370,
)
_sym_db.RegisterEnumDescriptor(_VERSIONING)

Versioning = enum_type_wrapper.EnumTypeWrapper(_VERSIONING)
VERSIONING_UNSPECIFIED = 0
VERSIONING_DISABLED = 1
VERSIONING_ENABLED = 2
VERSIONING_SUSPENDED = 3


_ACL_GRANT_PERMISSION = _descriptor.EnumDescriptor(
  name='Permission',
  full_name='yandex.cloud.storage.v1.ACL.Grant.Permission',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_FULL_CONTROL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_WRITE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_WRITE_ACP', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_READ', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PERMISSION_READ_ACP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=982,
  serialized_end=1145,
)
_sym_db.RegisterEnumDescriptor(_ACL_GRANT_PERMISSION)

_ACL_GRANT_GRANTTYPE = _descriptor.EnumDescriptor(
  name='GrantType',
  full_name='yandex.cloud.storage.v1.ACL.Grant.GrantType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GRANT_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANT_TYPE_ACCOUNT', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANT_TYPE_ALL_AUTHENTICATED_USERS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='GRANT_TYPE_ALL_USERS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1148,
  serialized_end=1277,
)
_sym_db.RegisterEnumDescriptor(_ACL_GRANT_GRANTTYPE)

_CORSRULE_METHOD = _descriptor.EnumDescriptor(
  name='Method',
  full_name='yandex.cloud.storage.v1.CorsRule.Method',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='METHOD_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METHOD_GET', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METHOD_HEAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METHOD_POST', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METHOD_PUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='METHOD_DELETE', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1677,
  serialized_end=1794,
)
_sym_db.RegisterEnumDescriptor(_CORSRULE_METHOD)

_WEBSITESETTINGS_PROTOCOL = _descriptor.EnumDescriptor(
  name='Protocol',
  full_name='yandex.cloud.storage.v1.WebsiteSettings.Protocol',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_HTTP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PROTOCOL_HTTPS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2550,
  serialized_end=2625,
)
_sym_db.RegisterEnumDescriptor(_WEBSITESETTINGS_PROTOCOL)

_HTTPSCONFIG_SOURCETYPE = _descriptor.EnumDescriptor(
  name='SourceType',
  full_name='yandex.cloud.storage.v1.HTTPSConfig.SourceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SOURCE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOURCE_TYPE_SELF_MANAGED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SOURCE_TYPE_MANAGED_BY_CERTIFICATE_MANAGER', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=5134,
  serialized_end=5253,
)
_sym_db.RegisterEnumDescriptor(_HTTPSCONFIG_SOURCETYPE)


_BUCKET = _descriptor.Descriptor(
  name='Bucket',
  full_name='yandex.cloud.storage.v1.Bucket',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.storage.v1.Bucket.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.Bucket.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.storage.v1.Bucket.folder_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anonymous_access_flags', full_name='yandex.cloud.storage.v1.Bucket.anonymous_access_flags', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_storage_class', full_name='yandex.cloud.storage.v1.Bucket.default_storage_class', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='versioning', full_name='yandex.cloud.storage.v1.Bucket.versioning', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='yandex.cloud.storage.v1.Bucket.max_size', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy', full_name='yandex.cloud.storage.v1.Bucket.policy', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='acl', full_name='yandex.cloud.storage.v1.Bucket.acl', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.storage.v1.Bucket.created_at', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='cors', full_name='yandex.cloud.storage.v1.Bucket.cors', index=10,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='website_settings', full_name='yandex.cloud.storage.v1.Bucket.website_settings', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lifecycle_rules', full_name='yandex.cloud.storage.v1.Bucket.lifecycle_rules', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=192,
  serialized_end=744,
)


_ACL_GRANT = _descriptor.Descriptor(
  name='Grant',
  full_name='yandex.cloud.storage.v1.ACL.Grant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='permission', full_name='yandex.cloud.storage.v1.ACL.Grant.permission', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grant_type', full_name='yandex.cloud.storage.v1.ACL.Grant.grant_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grantee_id', full_name='yandex.cloud.storage.v1.ACL.Grant.grantee_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ACL_GRANT_PERMISSION,
    _ACL_GRANT_GRANTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=1277,
)

_ACL = _descriptor.Descriptor(
  name='ACL',
  full_name='yandex.cloud.storage.v1.ACL',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='grants', full_name='yandex.cloud.storage.v1.ACL.grants', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_ACL_GRANT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=1277,
)


_ANONYMOUSACCESSFLAGS = _descriptor.Descriptor(
  name='AnonymousAccessFlags',
  full_name='yandex.cloud.storage.v1.AnonymousAccessFlags',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='read', full_name='yandex.cloud.storage.v1.AnonymousAccessFlags.read', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='list', full_name='yandex.cloud.storage.v1.AnonymousAccessFlags.list', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='config_read', full_name='yandex.cloud.storage.v1.AnonymousAccessFlags.config_read', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1280,
  serialized_end=1435,
)


_CORSRULE = _descriptor.Descriptor(
  name='CorsRule',
  full_name='yandex.cloud.storage.v1.CorsRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.storage.v1.CorsRule.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_methods', full_name='yandex.cloud.storage.v1.CorsRule.allowed_methods', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0\220\3101\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_headers', full_name='yandex.cloud.storage.v1.CorsRule.allowed_headers', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='allowed_origins', full_name='yandex.cloud.storage.v1.CorsRule.allowed_origins', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\002>0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expose_headers', full_name='yandex.cloud.storage.v1.CorsRule.expose_headers', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_age_seconds', full_name='yandex.cloud.storage.v1.CorsRule.max_age_seconds', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CORSRULE_METHOD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1438,
  serialized_end=1794,
)


_WEBSITESETTINGS_SCHEME = _descriptor.Descriptor(
  name='Scheme',
  full_name='yandex.cloud.storage.v1.WebsiteSettings.Scheme',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='yandex.cloud.storage.v1.WebsiteSettings.Scheme.protocol', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='yandex.cloud.storage.v1.WebsiteSettings.Scheme.hostname', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2003,
  serialized_end=2098,
)

_WEBSITESETTINGS_CONDITION = _descriptor.Descriptor(
  name='Condition',
  full_name='yandex.cloud.storage.v1.WebsiteSettings.Condition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_error_code_returned_equals', full_name='yandex.cloud.storage.v1.WebsiteSettings.Condition.http_error_code_returned_equals', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key_prefix_equals', full_name='yandex.cloud.storage.v1.WebsiteSettings.Condition.key_prefix_equals', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2100,
  serialized_end=2179,
)

_WEBSITESETTINGS_REDIRECT = _descriptor.Descriptor(
  name='Redirect',
  full_name='yandex.cloud.storage.v1.WebsiteSettings.Redirect',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='hostname', full_name='yandex.cloud.storage.v1.WebsiteSettings.Redirect.hostname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_redirect_code', full_name='yandex.cloud.storage.v1.WebsiteSettings.Redirect.http_redirect_code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\0243(0[1-9]|[1-9][0-9])', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='yandex.cloud.storage.v1.WebsiteSettings.Redirect.protocol', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replace_key_prefix_with', full_name='yandex.cloud.storage.v1.WebsiteSettings.Redirect.replace_key_prefix_with', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='replace_key_with', full_name='yandex.cloud.storage.v1.WebsiteSettings.Redirect.replace_key_with', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2182,
  serialized_end=2392,
)

_WEBSITESETTINGS_ROUTINGRULE = _descriptor.Descriptor(
  name='RoutingRule',
  full_name='yandex.cloud.storage.v1.WebsiteSettings.RoutingRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='condition', full_name='yandex.cloud.storage.v1.WebsiteSettings.RoutingRule.condition', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect', full_name='yandex.cloud.storage.v1.WebsiteSettings.RoutingRule.redirect', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2395,
  serialized_end=2548,
)

_WEBSITESETTINGS = _descriptor.Descriptor(
  name='WebsiteSettings',
  full_name='yandex.cloud.storage.v1.WebsiteSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='index', full_name='yandex.cloud.storage.v1.WebsiteSettings.index', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error', full_name='yandex.cloud.storage.v1.WebsiteSettings.error', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redirect_all_requests', full_name='yandex.cloud.storage.v1.WebsiteSettings.redirect_all_requests', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='routing_rules', full_name='yandex.cloud.storage.v1.WebsiteSettings.routing_rules', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WEBSITESETTINGS_SCHEME, _WEBSITESETTINGS_CONDITION, _WEBSITESETTINGS_REDIRECT, _WEBSITESETTINGS_ROUTINGRULE, ],
  enum_types=[
    _WEBSITESETTINGS_PROTOCOL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1797,
  serialized_end=2625,
)


_LIFECYCLERULE_AFTERDAYS = _descriptor.Descriptor(
  name='AfterDays',
  full_name='yandex.cloud.storage.v1.LifecycleRule.AfterDays',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='days_after_expiration', full_name='yandex.cloud.storage.v1.LifecycleRule.AfterDays.days_after_expiration', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3192,
  serialized_end=3263,
)

_LIFECYCLERULE_NONCURRENTEXPIRATION = _descriptor.Descriptor(
  name='NoncurrentExpiration',
  full_name='yandex.cloud.storage.v1.LifecycleRule.NoncurrentExpiration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='noncurrent_days', full_name='yandex.cloud.storage.v1.LifecycleRule.NoncurrentExpiration.noncurrent_days', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3265,
  serialized_end=3341,
)

_LIFECYCLERULE_NONCURRENTTRANSITION = _descriptor.Descriptor(
  name='NoncurrentTransition',
  full_name='yandex.cloud.storage.v1.LifecycleRule.NoncurrentTransition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='noncurrent_days', full_name='yandex.cloud.storage.v1.LifecycleRule.NoncurrentTransition.noncurrent_days', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_class', full_name='yandex.cloud.storage.v1.LifecycleRule.NoncurrentTransition.storage_class', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3343,
  serialized_end=3448,
)

_LIFECYCLERULE_TRANSITION = _descriptor.Descriptor(
  name='Transition',
  full_name='yandex.cloud.storage.v1.LifecycleRule.Transition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='yandex.cloud.storage.v1.LifecycleRule.Transition.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='days', full_name='yandex.cloud.storage.v1.LifecycleRule.Transition.days', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_class', full_name='yandex.cloud.storage.v1.LifecycleRule.Transition.storage_class', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3450,
  serialized_end=3576,
)

_LIFECYCLERULE_EXPIRATION = _descriptor.Descriptor(
  name='Expiration',
  full_name='yandex.cloud.storage.v1.LifecycleRule.Expiration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='date', full_name='yandex.cloud.storage.v1.LifecycleRule.Expiration.date', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='days', full_name='yandex.cloud.storage.v1.LifecycleRule.Expiration.days', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expired_object_delete_marker', full_name='yandex.cloud.storage.v1.LifecycleRule.Expiration.expired_object_delete_marker', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3579,
  serialized_end=3742,
)

_LIFECYCLERULE_RULEFILTER = _descriptor.Descriptor(
  name='RuleFilter',
  full_name='yandex.cloud.storage.v1.LifecycleRule.RuleFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='prefix', full_name='yandex.cloud.storage.v1.LifecycleRule.RuleFilter.prefix', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3744,
  serialized_end=3772,
)

_LIFECYCLERULE = _descriptor.Descriptor(
  name='LifecycleRule',
  full_name='yandex.cloud.storage.v1.LifecycleRule',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.storage.v1.LifecycleRule.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='enabled', full_name='yandex.cloud.storage.v1.LifecycleRule.enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.storage.v1.LifecycleRule.filter', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='yandex.cloud.storage.v1.LifecycleRule.expiration', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transitions', full_name='yandex.cloud.storage.v1.LifecycleRule.transitions', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='abort_incomplete_multipart_upload', full_name='yandex.cloud.storage.v1.LifecycleRule.abort_incomplete_multipart_upload', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='noncurrent_expiration', full_name='yandex.cloud.storage.v1.LifecycleRule.noncurrent_expiration', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='noncurrent_transitions', full_name='yandex.cloud.storage.v1.LifecycleRule.noncurrent_transitions', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LIFECYCLERULE_AFTERDAYS, _LIFECYCLERULE_NONCURRENTEXPIRATION, _LIFECYCLERULE_NONCURRENTTRANSITION, _LIFECYCLERULE_TRANSITION, _LIFECYCLERULE_EXPIRATION, _LIFECYCLERULE_RULEFILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2628,
  serialized_end=3772,
)


_COUNTERS = _descriptor.Descriptor(
  name='Counters',
  full_name='yandex.cloud.storage.v1.Counters',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='simple_object_size', full_name='yandex.cloud.storage.v1.Counters.simple_object_size', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='simple_object_count', full_name='yandex.cloud.storage.v1.Counters.simple_object_count', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='objects_parts_size', full_name='yandex.cloud.storage.v1.Counters.objects_parts_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='objects_parts_count', full_name='yandex.cloud.storage.v1.Counters.objects_parts_count', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multipart_objects_size', full_name='yandex.cloud.storage.v1.Counters.multipart_objects_size', index=4,
      number=5, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='multipart_objects_count', full_name='yandex.cloud.storage.v1.Counters.multipart_objects_count', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='active_multipart_count', full_name='yandex.cloud.storage.v1.Counters.active_multipart_count', index=6,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3775,
  serialized_end=3996,
)


_OPTIONALSIZEBYCLASS = _descriptor.Descriptor(
  name='OptionalSizeByClass',
  full_name='yandex.cloud.storage.v1.OptionalSizeByClass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_class', full_name='yandex.cloud.storage.v1.OptionalSizeByClass.storage_class', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_size', full_name='yandex.cloud.storage.v1.OptionalSizeByClass.class_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3998,
  serialized_end=4091,
)


_SIZEBYCLASS = _descriptor.Descriptor(
  name='SizeByClass',
  full_name='yandex.cloud.storage.v1.SizeByClass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_class', full_name='yandex.cloud.storage.v1.SizeByClass.storage_class', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='class_size', full_name='yandex.cloud.storage.v1.SizeByClass.class_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4093,
  serialized_end=4149,
)


_COUNTERSBYCLASS = _descriptor.Descriptor(
  name='CountersByClass',
  full_name='yandex.cloud.storage.v1.CountersByClass',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='storage_class', full_name='yandex.cloud.storage.v1.CountersByClass.storage_class', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='counters', full_name='yandex.cloud.storage.v1.CountersByClass.counters', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4151,
  serialized_end=4244,
)


_BUCKETSTATS = _descriptor.Descriptor(
  name='BucketStats',
  full_name='yandex.cloud.storage.v1.BucketStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.BucketStats.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_size', full_name='yandex.cloud.storage.v1.BucketStats.max_size', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='used_size', full_name='yandex.cloud.storage.v1.BucketStats.used_size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_class_max_sizes', full_name='yandex.cloud.storage.v1.BucketStats.storage_class_max_sizes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_class_used_sizes', full_name='yandex.cloud.storage.v1.BucketStats.storage_class_used_sizes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='storage_class_counters', full_name='yandex.cloud.storage.v1.BucketStats.storage_class_counters', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_storage_class', full_name='yandex.cloud.storage.v1.BucketStats.default_storage_class', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anonymous_access_flags', full_name='yandex.cloud.storage.v1.BucketStats.anonymous_access_flags', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='yandex.cloud.storage.v1.BucketStats.created_at', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='updated_at', full_name='yandex.cloud.storage.v1.BucketStats.updated_at', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4247,
  serialized_end=4801,
)


_HTTPSCONFIG = _descriptor.Descriptor(
  name='HTTPSConfig',
  full_name='yandex.cloud.storage.v1.HTTPSConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.storage.v1.HTTPSConfig.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_type', full_name='yandex.cloud.storage.v1.HTTPSConfig.source_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issuer', full_name='yandex.cloud.storage.v1.HTTPSConfig.issuer', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subject', full_name='yandex.cloud.storage.v1.HTTPSConfig.subject', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dns_names', full_name='yandex.cloud.storage.v1.HTTPSConfig.dns_names', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_before', full_name='yandex.cloud.storage.v1.HTTPSConfig.not_before', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='not_after', full_name='yandex.cloud.storage.v1.HTTPSConfig.not_after', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='certificate_id', full_name='yandex.cloud.storage.v1.HTTPSConfig.certificate_id', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HTTPSCONFIG_SOURCETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4804,
  serialized_end=5253,
)

_BUCKET.fields_by_name['anonymous_access_flags'].message_type = _ANONYMOUSACCESSFLAGS
_BUCKET.fields_by_name['versioning'].enum_type = _VERSIONING
_BUCKET.fields_by_name['policy'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_BUCKET.fields_by_name['acl'].message_type = _ACL
_BUCKET.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BUCKET.fields_by_name['cors'].message_type = _CORSRULE
_BUCKET.fields_by_name['website_settings'].message_type = _WEBSITESETTINGS
_BUCKET.fields_by_name['lifecycle_rules'].message_type = _LIFECYCLERULE
_ACL_GRANT.fields_by_name['permission'].enum_type = _ACL_GRANT_PERMISSION
_ACL_GRANT.fields_by_name['grant_type'].enum_type = _ACL_GRANT_GRANTTYPE
_ACL_GRANT.containing_type = _ACL
_ACL_GRANT_PERMISSION.containing_type = _ACL_GRANT
_ACL_GRANT_GRANTTYPE.containing_type = _ACL_GRANT
_ACL.fields_by_name['grants'].message_type = _ACL_GRANT
_ANONYMOUSACCESSFLAGS.fields_by_name['read'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ANONYMOUSACCESSFLAGS.fields_by_name['list'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_ANONYMOUSACCESSFLAGS.fields_by_name['config_read'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_CORSRULE.fields_by_name['allowed_methods'].enum_type = _CORSRULE_METHOD
_CORSRULE.fields_by_name['max_age_seconds'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_CORSRULE_METHOD.containing_type = _CORSRULE
_WEBSITESETTINGS_SCHEME.fields_by_name['protocol'].enum_type = _WEBSITESETTINGS_PROTOCOL
_WEBSITESETTINGS_SCHEME.containing_type = _WEBSITESETTINGS
_WEBSITESETTINGS_CONDITION.containing_type = _WEBSITESETTINGS
_WEBSITESETTINGS_REDIRECT.fields_by_name['protocol'].enum_type = _WEBSITESETTINGS_PROTOCOL
_WEBSITESETTINGS_REDIRECT.containing_type = _WEBSITESETTINGS
_WEBSITESETTINGS_ROUTINGRULE.fields_by_name['condition'].message_type = _WEBSITESETTINGS_CONDITION
_WEBSITESETTINGS_ROUTINGRULE.fields_by_name['redirect'].message_type = _WEBSITESETTINGS_REDIRECT
_WEBSITESETTINGS_ROUTINGRULE.containing_type = _WEBSITESETTINGS
_WEBSITESETTINGS.fields_by_name['redirect_all_requests'].message_type = _WEBSITESETTINGS_SCHEME
_WEBSITESETTINGS.fields_by_name['routing_rules'].message_type = _WEBSITESETTINGS_ROUTINGRULE
_WEBSITESETTINGS_PROTOCOL.containing_type = _WEBSITESETTINGS
_LIFECYCLERULE_AFTERDAYS.fields_by_name['days_after_expiration'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_LIFECYCLERULE_AFTERDAYS.containing_type = _LIFECYCLERULE
_LIFECYCLERULE_NONCURRENTEXPIRATION.fields_by_name['noncurrent_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_LIFECYCLERULE_NONCURRENTEXPIRATION.containing_type = _LIFECYCLERULE
_LIFECYCLERULE_NONCURRENTTRANSITION.fields_by_name['noncurrent_days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_LIFECYCLERULE_NONCURRENTTRANSITION.containing_type = _LIFECYCLERULE
_LIFECYCLERULE_TRANSITION.fields_by_name['date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LIFECYCLERULE_TRANSITION.fields_by_name['days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_LIFECYCLERULE_TRANSITION.containing_type = _LIFECYCLERULE
_LIFECYCLERULE_EXPIRATION.fields_by_name['date'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_LIFECYCLERULE_EXPIRATION.fields_by_name['days'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_LIFECYCLERULE_EXPIRATION.fields_by_name['expired_object_delete_marker'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_LIFECYCLERULE_EXPIRATION.containing_type = _LIFECYCLERULE
_LIFECYCLERULE_RULEFILTER.containing_type = _LIFECYCLERULE
_LIFECYCLERULE.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_LIFECYCLERULE.fields_by_name['filter'].message_type = _LIFECYCLERULE_RULEFILTER
_LIFECYCLERULE.fields_by_name['expiration'].message_type = _LIFECYCLERULE_EXPIRATION
_LIFECYCLERULE.fields_by_name['transitions'].message_type = _LIFECYCLERULE_TRANSITION
_LIFECYCLERULE.fields_by_name['abort_incomplete_multipart_upload'].message_type = _LIFECYCLERULE_AFTERDAYS
_LIFECYCLERULE.fields_by_name['noncurrent_expiration'].message_type = _LIFECYCLERULE_NONCURRENTEXPIRATION
_LIFECYCLERULE.fields_by_name['noncurrent_transitions'].message_type = _LIFECYCLERULE_NONCURRENTTRANSITION
_OPTIONALSIZEBYCLASS.fields_by_name['class_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_COUNTERSBYCLASS.fields_by_name['counters'].message_type = _COUNTERS
_BUCKETSTATS.fields_by_name['max_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_BUCKETSTATS.fields_by_name['storage_class_max_sizes'].message_type = _OPTIONALSIZEBYCLASS
_BUCKETSTATS.fields_by_name['storage_class_used_sizes'].message_type = _SIZEBYCLASS
_BUCKETSTATS.fields_by_name['storage_class_counters'].message_type = _COUNTERSBYCLASS
_BUCKETSTATS.fields_by_name['default_storage_class'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_BUCKETSTATS.fields_by_name['anonymous_access_flags'].message_type = _ANONYMOUSACCESSFLAGS
_BUCKETSTATS.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_BUCKETSTATS.fields_by_name['updated_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HTTPSCONFIG.fields_by_name['source_type'].enum_type = _HTTPSCONFIG_SOURCETYPE
_HTTPSCONFIG.fields_by_name['issuer'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_HTTPSCONFIG.fields_by_name['subject'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_HTTPSCONFIG.fields_by_name['not_before'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HTTPSCONFIG.fields_by_name['not_after'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_HTTPSCONFIG_SOURCETYPE.containing_type = _HTTPSCONFIG
DESCRIPTOR.message_types_by_name['Bucket'] = _BUCKET
DESCRIPTOR.message_types_by_name['ACL'] = _ACL
DESCRIPTOR.message_types_by_name['AnonymousAccessFlags'] = _ANONYMOUSACCESSFLAGS
DESCRIPTOR.message_types_by_name['CorsRule'] = _CORSRULE
DESCRIPTOR.message_types_by_name['WebsiteSettings'] = _WEBSITESETTINGS
DESCRIPTOR.message_types_by_name['LifecycleRule'] = _LIFECYCLERULE
DESCRIPTOR.message_types_by_name['Counters'] = _COUNTERS
DESCRIPTOR.message_types_by_name['OptionalSizeByClass'] = _OPTIONALSIZEBYCLASS
DESCRIPTOR.message_types_by_name['SizeByClass'] = _SIZEBYCLASS
DESCRIPTOR.message_types_by_name['CountersByClass'] = _COUNTERSBYCLASS
DESCRIPTOR.message_types_by_name['BucketStats'] = _BUCKETSTATS
DESCRIPTOR.message_types_by_name['HTTPSConfig'] = _HTTPSCONFIG
DESCRIPTOR.enum_types_by_name['Versioning'] = _VERSIONING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Bucket = _reflection.GeneratedProtocolMessageType('Bucket', (_message.Message,), {
  'DESCRIPTOR' : _BUCKET,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.Bucket)
  })
_sym_db.RegisterMessage(Bucket)

ACL = _reflection.GeneratedProtocolMessageType('ACL', (_message.Message,), {

  'Grant' : _reflection.GeneratedProtocolMessageType('Grant', (_message.Message,), {
    'DESCRIPTOR' : _ACL_GRANT,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.ACL.Grant)
    })
  ,
  'DESCRIPTOR' : _ACL,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.ACL)
  })
_sym_db.RegisterMessage(ACL)
_sym_db.RegisterMessage(ACL.Grant)

AnonymousAccessFlags = _reflection.GeneratedProtocolMessageType('AnonymousAccessFlags', (_message.Message,), {
  'DESCRIPTOR' : _ANONYMOUSACCESSFLAGS,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.AnonymousAccessFlags)
  })
_sym_db.RegisterMessage(AnonymousAccessFlags)

CorsRule = _reflection.GeneratedProtocolMessageType('CorsRule', (_message.Message,), {
  'DESCRIPTOR' : _CORSRULE,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.CorsRule)
  })
_sym_db.RegisterMessage(CorsRule)

WebsiteSettings = _reflection.GeneratedProtocolMessageType('WebsiteSettings', (_message.Message,), {

  'Scheme' : _reflection.GeneratedProtocolMessageType('Scheme', (_message.Message,), {
    'DESCRIPTOR' : _WEBSITESETTINGS_SCHEME,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.WebsiteSettings.Scheme)
    })
  ,

  'Condition' : _reflection.GeneratedProtocolMessageType('Condition', (_message.Message,), {
    'DESCRIPTOR' : _WEBSITESETTINGS_CONDITION,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.WebsiteSettings.Condition)
    })
  ,

  'Redirect' : _reflection.GeneratedProtocolMessageType('Redirect', (_message.Message,), {
    'DESCRIPTOR' : _WEBSITESETTINGS_REDIRECT,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.WebsiteSettings.Redirect)
    })
  ,

  'RoutingRule' : _reflection.GeneratedProtocolMessageType('RoutingRule', (_message.Message,), {
    'DESCRIPTOR' : _WEBSITESETTINGS_ROUTINGRULE,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.WebsiteSettings.RoutingRule)
    })
  ,
  'DESCRIPTOR' : _WEBSITESETTINGS,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.WebsiteSettings)
  })
_sym_db.RegisterMessage(WebsiteSettings)
_sym_db.RegisterMessage(WebsiteSettings.Scheme)
_sym_db.RegisterMessage(WebsiteSettings.Condition)
_sym_db.RegisterMessage(WebsiteSettings.Redirect)
_sym_db.RegisterMessage(WebsiteSettings.RoutingRule)

LifecycleRule = _reflection.GeneratedProtocolMessageType('LifecycleRule', (_message.Message,), {

  'AfterDays' : _reflection.GeneratedProtocolMessageType('AfterDays', (_message.Message,), {
    'DESCRIPTOR' : _LIFECYCLERULE_AFTERDAYS,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.LifecycleRule.AfterDays)
    })
  ,

  'NoncurrentExpiration' : _reflection.GeneratedProtocolMessageType('NoncurrentExpiration', (_message.Message,), {
    'DESCRIPTOR' : _LIFECYCLERULE_NONCURRENTEXPIRATION,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.LifecycleRule.NoncurrentExpiration)
    })
  ,

  'NoncurrentTransition' : _reflection.GeneratedProtocolMessageType('NoncurrentTransition', (_message.Message,), {
    'DESCRIPTOR' : _LIFECYCLERULE_NONCURRENTTRANSITION,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.LifecycleRule.NoncurrentTransition)
    })
  ,

  'Transition' : _reflection.GeneratedProtocolMessageType('Transition', (_message.Message,), {
    'DESCRIPTOR' : _LIFECYCLERULE_TRANSITION,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.LifecycleRule.Transition)
    })
  ,

  'Expiration' : _reflection.GeneratedProtocolMessageType('Expiration', (_message.Message,), {
    'DESCRIPTOR' : _LIFECYCLERULE_EXPIRATION,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.LifecycleRule.Expiration)
    })
  ,

  'RuleFilter' : _reflection.GeneratedProtocolMessageType('RuleFilter', (_message.Message,), {
    'DESCRIPTOR' : _LIFECYCLERULE_RULEFILTER,
    '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.LifecycleRule.RuleFilter)
    })
  ,
  'DESCRIPTOR' : _LIFECYCLERULE,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.LifecycleRule)
  })
_sym_db.RegisterMessage(LifecycleRule)
_sym_db.RegisterMessage(LifecycleRule.AfterDays)
_sym_db.RegisterMessage(LifecycleRule.NoncurrentExpiration)
_sym_db.RegisterMessage(LifecycleRule.NoncurrentTransition)
_sym_db.RegisterMessage(LifecycleRule.Transition)
_sym_db.RegisterMessage(LifecycleRule.Expiration)
_sym_db.RegisterMessage(LifecycleRule.RuleFilter)

Counters = _reflection.GeneratedProtocolMessageType('Counters', (_message.Message,), {
  'DESCRIPTOR' : _COUNTERS,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.Counters)
  })
_sym_db.RegisterMessage(Counters)

OptionalSizeByClass = _reflection.GeneratedProtocolMessageType('OptionalSizeByClass', (_message.Message,), {
  'DESCRIPTOR' : _OPTIONALSIZEBYCLASS,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.OptionalSizeByClass)
  })
_sym_db.RegisterMessage(OptionalSizeByClass)

SizeByClass = _reflection.GeneratedProtocolMessageType('SizeByClass', (_message.Message,), {
  'DESCRIPTOR' : _SIZEBYCLASS,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.SizeByClass)
  })
_sym_db.RegisterMessage(SizeByClass)

CountersByClass = _reflection.GeneratedProtocolMessageType('CountersByClass', (_message.Message,), {
  'DESCRIPTOR' : _COUNTERSBYCLASS,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.CountersByClass)
  })
_sym_db.RegisterMessage(CountersByClass)

BucketStats = _reflection.GeneratedProtocolMessageType('BucketStats', (_message.Message,), {
  'DESCRIPTOR' : _BUCKETSTATS,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.BucketStats)
  })
_sym_db.RegisterMessage(BucketStats)

HTTPSConfig = _reflection.GeneratedProtocolMessageType('HTTPSConfig', (_message.Message,), {
  'DESCRIPTOR' : _HTTPSCONFIG,
  '__module__' : 'yandex.cloud.storage.v1.bucket_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.storage.v1.HTTPSConfig)
  })
_sym_db.RegisterMessage(HTTPSConfig)


DESCRIPTOR._options = None
_ACL_GRANT.fields_by_name['permission']._options = None
_ACL_GRANT.fields_by_name['grant_type']._options = None
_CORSRULE.fields_by_name['allowed_methods']._options = None
_CORSRULE.fields_by_name['allowed_origins']._options = None
_WEBSITESETTINGS_REDIRECT.fields_by_name['http_redirect_code']._options = None
_LIFECYCLERULE_NONCURRENTTRANSITION.fields_by_name['storage_class']._options = None
_LIFECYCLERULE_TRANSITION.fields_by_name['storage_class']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/monitoring/v3/title_widget.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/monitoring/v3/title_widget.proto',
  package='yandex.cloud.monitoring.v3',
  syntax='proto3',
  serialized_options=b'\n\036yandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoring',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n-yandex/cloud/monitoring/v3/title_widget.proto\x12\x1ayandex.cloud.monitoring.v3\"\xce\x01\n\x0bTitleWidget\x12\x0c\n\x04text\x18\x01 \x01(\t\x12?\n\x04size\x18\x02 \x01(\x0e\x32\x31.yandex.cloud.monitoring.v3.TitleWidget.TitleSize\"p\n\tTitleSize\x12\x1a\n\x16TITLE_SIZE_UNSPECIFIED\x10\x00\x12\x11\n\rTITLE_SIZE_XS\x10\x01\x12\x10\n\x0cTITLE_SIZE_S\x10\x02\x12\x10\n\x0cTITLE_SIZE_M\x10\x03\x12\x10\n\x0cTITLE_SIZE_L\x10\x04\x42k\n\x1eyandex.cloud.api.monitoring.v3ZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/monitoring/v3;monitoringb\x06proto3'
)



_TITLEWIDGET_TITLESIZE = _descriptor.EnumDescriptor(
  name='TitleSize',
  full_name='yandex.cloud.monitoring.v3.TitleWidget.TitleSize',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_XS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_S', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_M', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TITLE_SIZE_L', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=172,
  serialized_end=284,
)
_sym_db.RegisterEnumDescriptor(_TITLEWIDGET_TITLESIZE)


_TITLEWIDGET = _descriptor.Descriptor(
  name='TitleWidget',
  full_name='yandex.cloud.monitoring.v3.TitleWidget',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='yandex.cloud.monitoring.v3.TitleWidget.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='yandex.cloud.monitoring.v3.TitleWidget.size', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TITLEWIDGET_TITLESIZE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=78,
  serialized_end=284,
)

_TITLEWIDGET.fields_by_name['size'].enum_type = _TITLEWIDGET_TITLESIZE
_TITLEWIDGET_TITLESIZE.containing_type = _TITLEWIDGET
DESCRIPTOR.message_types_by_name['TitleWidget'] = _TITLEWIDGET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TitleWidget = _reflection.GeneratedProtocolMessageType('TitleWidget', (_message.Message,), {
  'DESCRIPTOR' : _TITLEWIDGET,
  '__module__' : 'yandex.cloud.monitoring.v3.title_widget_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.monitoring.v3.TitleWidget)
  })
_sym_db.RegisterMessage(TitleWidget)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/awscompatibility/access_key_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1.awscompatibility import access_key_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_awscompatibility_dot_access__key__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/iam/v1/awscompatibility/access_key_service.proto',
  package='yandex.cloud.iam.v1.awscompatibility',
  syntax='proto3',
  serialized_options=b'\n(yandex.cloud.api.iam.v1.awscompatibilityZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/awscompatibility;awscompatibility',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=yandex/cloud/iam/v1/awscompatibility/access_key_service.proto\x12$yandex.cloud.iam.v1.awscompatibility\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a\x35yandex/cloud/iam/v1/awscompatibility/access_key.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\":\n\x13GetAccessKeyRequest\x12#\n\raccess_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"{\n\x15ListAccessKeysRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"w\n\x16ListAccessKeysResponse\x12\x44\n\x0b\x61\x63\x63\x65ss_keys\x18\x01 \x03(\x0b\x32/.yandex.cloud.iam.v1.awscompatibility.AccessKey\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"^\n\x16\x43reateAccessKeyRequest\x12$\n\x12service_account_id\x18\x01 \x01(\tB\x08\x8a\xc8\x31\x04<=50\x12\x1e\n\x0b\x64\x65scription\x18\x02 \x01(\tB\t\x8a\xc8\x31\x05<=256\"n\n\x17\x43reateAccessKeyResponse\x12\x43\n\naccess_key\x18\x01 \x01(\x0b\x32/.yandex.cloud.iam.v1.awscompatibility.AccessKey\x12\x0e\n\x06secret\x18\x02 \x01(\t\"\x8e\x01\n\x16UpdateAccessKeyRequest\x12#\n\raccess_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\"0\n\x17UpdateAccessKeyMetadata\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\"=\n\x16\x44\x65leteAccessKeyRequest\x12#\n\raccess_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"0\n\x17\x44\x65leteAccessKeyMetadata\x12\x15\n\raccess_key_id\x18\x01 \x01(\t\"\x83\x01\n\x1eListAccessKeyOperationsRequest\x12#\n\raccess_key_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"q\n\x1fListAccessKeyOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xcb\t\n\x10\x41\x63\x63\x65ssKeyService\x12\xaf\x01\n\x04List\x12;.yandex.cloud.iam.v1.awscompatibility.ListAccessKeysRequest\x1a<.yandex.cloud.iam.v1.awscompatibility.ListAccessKeysResponse\",\x82\xd3\xe4\x93\x02&\x12$/iam/aws-compatibility/v1/accessKeys\x12\xaf\x01\n\x03Get\x12\x39.yandex.cloud.iam.v1.awscompatibility.GetAccessKeyRequest\x1a/.yandex.cloud.iam.v1.awscompatibility.AccessKey\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/iam/aws-compatibility/v1/accessKeys/{access_key_id}\x12\xb6\x01\n\x06\x43reate\x12<.yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyRequest\x1a=.yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyResponse\"/\x82\xd3\xe4\x93\x02)\"$/iam/aws-compatibility/v1/accessKeys:\x01*\x12\xd2\x01\n\x06Update\x12<.yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyRequest\x1a!.yandex.cloud.operation.Operation\"g\x82\xd3\xe4\x93\x02\x39\x32\x34/iam/aws-compatibility/v1/accessKeys/{access_key_id}:\x01*\xb2\xd2*$\n\x17UpdateAccessKeyMetadata\x12\tAccessKey\x12\xdb\x01\n\x06\x44\x65lete\x12<.yandex.cloud.iam.v1.awscompatibility.DeleteAccessKeyRequest\x1a!.yandex.cloud.operation.Operation\"p\x82\xd3\xe4\x93\x02\x36*4/iam/aws-compatibility/v1/accessKeys/{access_key_id}\xb2\xd2*0\n\x17\x44\x65leteAccessKeyMetadata\x12\x15google.protobuf.Empty\x12\xe6\x01\n\x0eListOperations\x12\x44.yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsRequest\x1a\x45.yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/iam/aws-compatibility/v1/accessKeys/{access_key_id}/operationsB\x85\x01\n(yandex.cloud.api.iam.v1.awscompatibilityZYgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/awscompatibility;awscompatibilityb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_iam_dot_v1_dot_awscompatibility_dot_access__key__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETACCESSKEYREQUEST = _descriptor.Descriptor(
  name='GetAccessKeyRequest',
  full_name='yandex.cloud.iam.v1.awscompatibility.GetAccessKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key_id', full_name='yandex.cloud.iam.v1.awscompatibility.GetAccessKeyRequest.access_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=327,
  serialized_end=385,
)


_LISTACCESSKEYSREQUEST = _descriptor.Descriptor(
  name='ListAccessKeysRequest',
  full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeysRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeysRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeysRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeysRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=387,
  serialized_end=510,
)


_LISTACCESSKEYSRESPONSE = _descriptor.Descriptor(
  name='ListAccessKeysResponse',
  full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeysResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_keys', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeysResponse.access_keys', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeysResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=631,
)


_CREATEACCESSKEYREQUEST = _descriptor.Descriptor(
  name='CreateAccessKeyRequest',
  full_name='yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_account_id', full_name='yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyRequest.service_account_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=633,
  serialized_end=727,
)


_CREATEACCESSKEYRESPONSE = _descriptor.Descriptor(
  name='CreateAccessKeyResponse',
  full_name='yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key', full_name='yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyResponse.access_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='secret', full_name='yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyResponse.secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=729,
  serialized_end=839,
)


_UPDATEACCESSKEYREQUEST = _descriptor.Descriptor(
  name='UpdateAccessKeyRequest',
  full_name='yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key_id', full_name='yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyRequest.access_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=842,
  serialized_end=984,
)


_UPDATEACCESSKEYMETADATA = _descriptor.Descriptor(
  name='UpdateAccessKeyMetadata',
  full_name='yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key_id', full_name='yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyMetadata.access_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=986,
  serialized_end=1034,
)


_DELETEACCESSKEYREQUEST = _descriptor.Descriptor(
  name='DeleteAccessKeyRequest',
  full_name='yandex.cloud.iam.v1.awscompatibility.DeleteAccessKeyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key_id', full_name='yandex.cloud.iam.v1.awscompatibility.DeleteAccessKeyRequest.access_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1036,
  serialized_end=1097,
)


_DELETEACCESSKEYMETADATA = _descriptor.Descriptor(
  name='DeleteAccessKeyMetadata',
  full_name='yandex.cloud.iam.v1.awscompatibility.DeleteAccessKeyMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key_id', full_name='yandex.cloud.iam.v1.awscompatibility.DeleteAccessKeyMetadata.access_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1099,
  serialized_end=1147,
)


_LISTACCESSKEYOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListAccessKeyOperationsRequest',
  full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key_id', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsRequest.access_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1150,
  serialized_end=1281,
)


_LISTACCESSKEYOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListAccessKeyOperationsResponse',
  full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1283,
  serialized_end=1396,
)

_LISTACCESSKEYSRESPONSE.fields_by_name['access_keys'].message_type = yandex_dot_cloud_dot_iam_dot_v1_dot_awscompatibility_dot_access__key__pb2._ACCESSKEY
_CREATEACCESSKEYRESPONSE.fields_by_name['access_key'].message_type = yandex_dot_cloud_dot_iam_dot_v1_dot_awscompatibility_dot_access__key__pb2._ACCESSKEY
_UPDATEACCESSKEYREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTACCESSKEYOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetAccessKeyRequest'] = _GETACCESSKEYREQUEST
DESCRIPTOR.message_types_by_name['ListAccessKeysRequest'] = _LISTACCESSKEYSREQUEST
DESCRIPTOR.message_types_by_name['ListAccessKeysResponse'] = _LISTACCESSKEYSRESPONSE
DESCRIPTOR.message_types_by_name['CreateAccessKeyRequest'] = _CREATEACCESSKEYREQUEST
DESCRIPTOR.message_types_by_name['CreateAccessKeyResponse'] = _CREATEACCESSKEYRESPONSE
DESCRIPTOR.message_types_by_name['UpdateAccessKeyRequest'] = _UPDATEACCESSKEYREQUEST
DESCRIPTOR.message_types_by_name['UpdateAccessKeyMetadata'] = _UPDATEACCESSKEYMETADATA
DESCRIPTOR.message_types_by_name['DeleteAccessKeyRequest'] = _DELETEACCESSKEYREQUEST
DESCRIPTOR.message_types_by_name['DeleteAccessKeyMetadata'] = _DELETEACCESSKEYMETADATA
DESCRIPTOR.message_types_by_name['ListAccessKeyOperationsRequest'] = _LISTACCESSKEYOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListAccessKeyOperationsResponse'] = _LISTACCESSKEYOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetAccessKeyRequest = _reflection.GeneratedProtocolMessageType('GetAccessKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCESSKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.GetAccessKeyRequest)
  })
_sym_db.RegisterMessage(GetAccessKeyRequest)

ListAccessKeysRequest = _reflection.GeneratedProtocolMessageType('ListAccessKeysRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCESSKEYSREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.ListAccessKeysRequest)
  })
_sym_db.RegisterMessage(ListAccessKeysRequest)

ListAccessKeysResponse = _reflection.GeneratedProtocolMessageType('ListAccessKeysResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCESSKEYSRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.ListAccessKeysResponse)
  })
_sym_db.RegisterMessage(ListAccessKeysResponse)

CreateAccessKeyRequest = _reflection.GeneratedProtocolMessageType('CreateAccessKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCESSKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyRequest)
  })
_sym_db.RegisterMessage(CreateAccessKeyRequest)

CreateAccessKeyResponse = _reflection.GeneratedProtocolMessageType('CreateAccessKeyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEACCESSKEYRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.CreateAccessKeyResponse)
  })
_sym_db.RegisterMessage(CreateAccessKeyResponse)

UpdateAccessKeyRequest = _reflection.GeneratedProtocolMessageType('UpdateAccessKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCESSKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyRequest)
  })
_sym_db.RegisterMessage(UpdateAccessKeyRequest)

UpdateAccessKeyMetadata = _reflection.GeneratedProtocolMessageType('UpdateAccessKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEACCESSKEYMETADATA,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.UpdateAccessKeyMetadata)
  })
_sym_db.RegisterMessage(UpdateAccessKeyMetadata)

DeleteAccessKeyRequest = _reflection.GeneratedProtocolMessageType('DeleteAccessKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCESSKEYREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.DeleteAccessKeyRequest)
  })
_sym_db.RegisterMessage(DeleteAccessKeyRequest)

DeleteAccessKeyMetadata = _reflection.GeneratedProtocolMessageType('DeleteAccessKeyMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEACCESSKEYMETADATA,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.DeleteAccessKeyMetadata)
  })
_sym_db.RegisterMessage(DeleteAccessKeyMetadata)

ListAccessKeyOperationsRequest = _reflection.GeneratedProtocolMessageType('ListAccessKeyOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCESSKEYOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsRequest)
  })
_sym_db.RegisterMessage(ListAccessKeyOperationsRequest)

ListAccessKeyOperationsResponse = _reflection.GeneratedProtocolMessageType('ListAccessKeyOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTACCESSKEYOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.iam.v1.awscompatibility.access_key_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.iam.v1.awscompatibility.ListAccessKeyOperationsResponse)
  })
_sym_db.RegisterMessage(ListAccessKeyOperationsResponse)


DESCRIPTOR._options = None
_GETACCESSKEYREQUEST.fields_by_name['access_key_id']._options = None
_LISTACCESSKEYSREQUEST.fields_by_name['service_account_id']._options = None
_LISTACCESSKEYSREQUEST.fields_by_name['page_size']._options = None
_LISTACCESSKEYSREQUEST.fields_by_name['page_token']._options = None
_CREATEACCESSKEYREQUEST.fields_by_name['service_account_id']._options = None
_CREATEACCESSKEYREQUEST.fields_by_name['description']._options = None
_UPDATEACCESSKEYREQUEST.fields_by_name['access_key_id']._options = None
_UPDATEACCESSKEYREQUEST.fields_by_name['description']._options = None
_DELETEACCESSKEYREQUEST.fields_by_name['access_key_id']._options = None
_LISTACCESSKEYOPERATIONSREQUEST.fields_by_name['access_key_id']._options = None
_LISTACCESSKEYOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTACCESSKEYOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_ACCESSKEYSERVICE = _descriptor.ServiceDescriptor(
  name='AccessKeyService',
  full_name='yandex.cloud.iam.v1.awscompatibility.AccessKeyService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1399,
  serialized_end=2626,
  methods=[
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.iam.v1.awscompatibility.AccessKeyService.List',
    index=0,
    containing_service=None,
    input_type=_LISTACCESSKEYSREQUEST,
    output_type=_LISTACCESSKEYSRESPONSE,
    serialized_options=b'\202\323\344\223\002&\022$/iam/aws-compatibility/v1/accessKeys',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.iam.v1.awscompatibility.AccessKeyService.Get',
    index=1,
    containing_service=None,
    input_type=_GETACCESSKEYREQUEST,
    output_type=yandex_dot_cloud_dot_iam_dot_v1_dot_awscompatibility_dot_access__key__pb2._ACCESSKEY,
    serialized_options=b'\202\323\344\223\0026\0224/iam/aws-compatibility/v1/accessKeys/{access_key_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.iam.v1.awscompatibility.AccessKeyService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEACCESSKEYREQUEST,
    output_type=_CREATEACCESSKEYRESPONSE,
    serialized_options=b'\202\323\344\223\002)\"$/iam/aws-compatibility/v1/accessKeys:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.iam.v1.awscompatibility.AccessKeyService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEACCESSKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002924/iam/aws-compatibility/v1/accessKeys/{access_key_id}:\001*\262\322*$\n\027UpdateAccessKeyMetadata\022\tAccessKey',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.iam.v1.awscompatibility.AccessKeyService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEACCESSKEYREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026*4/iam/aws-compatibility/v1/accessKeys/{access_key_id}\262\322*0\n\027DeleteAccessKeyMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.iam.v1.awscompatibility.AccessKeyService.ListOperations',
    index=5,
    containing_service=None,
    input_type=_LISTACCESSKEYOPERATIONSREQUEST,
    output_type=_LISTACCESSKEYOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002A\022?/iam/aws-compatibility/v1/accessKeys/{access_key_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_ACCESSKEYSERVICE)

DESCRIPTOR.services_by_name['AccessKeyService'] = _ACCESSKEYSERVICE

# @@protoc_insertion_point(module_scope)
